@@ -262,14 +262,6 @@ def events() -> list:
     return processing.__events
 
 
-def quitter(value=None):
-    global __quitter
-    if value is None:
-        return __quitter
-    elif value is False:
-        __quitter = False
-
-
 def run(globales):
     global __key_pressed, __click, __click_down, __click_up, keys, __quitter, var_globales, __frameCount, clock, secondes
     global __tempo_seconde, __tempo_centieme, centiemes, __events, __mouse_wheel, __resized
@@ -283,7 +275,7 @@ def run(globales):
         __events = pygame.event.get()
         for event in __events:
             if event.type == pygame.QUIT:
-                if globales.get('quit'):
+                if globales.get('exit'):
                     __quitter = True
                 else:
                     quit()
@@ -316,7 +308,7 @@ def run(globales):
                 globales['draw']()
                 reset()
         if __quitter:
-            globales['quit']()
+            globales['exit']()
         pygame.display.update()  # Or pygame.display.flip()
         __frameCount += 1
         __click_down = False
