@@ -34,4 +34,24 @@ class Tempo:
 
     def is_off(self):
         """renvoie True si la temporisation est à off."""
-        return not self.is_on()
\ No newline at end of file
+        return not self.is_on()
+
+class Monostable(Tempo):
+    def __init__(self, duree_ms: int):
+        super().__init__(duree_ms)
+        self.__on = False
+        self.__stop = False
+
+    def fin(self):
+        """renvoie True lorsque la temporisation est terminée. Pour notre exemple au bout de 500 ms."""
+        if not self.__stop and ((processing.frameCount() - self.depart) / processing.getFrameRate()) * 1000 >= self.duree_ms:
+            self.__on = not self.__on
+            self.__stop = True
+            return True
+        else:
+            return False
+
+    def reset(self):
+        """force le redémarrage de la temporisation."""
+        self.depart = processing.frameCount()
+        self.__stop = False
\ No newline at end of file
