@@ -2,7 +2,7 @@ import likeprocessing.processing as processing
 from likeprocessing.trigo import *
 
 
-def translate(x: [int, None] = None, y: [int, None] = None)->[tuple, None]:
+def translation(x: [int, None] = None, y: [int, None] = None)->[tuple, None]:
     """initialise les valeurs relatives du déplacement et renvoie la valeur précédente de celui-ci (tuple)"""
     st = processing.get_dx(),processing.get_dy()
     if x is not None:
@@ -99,7 +99,7 @@ def symetrie_x(points: list) -> list:
     return pts
 
 
-def translation(points: list) -> list:
+def translation_list(points: list) -> list:
     """execute une translation sur une liste de points"""
     if processing.get_dx() == 0 and processing.get_dy() == 0:
         return points
@@ -122,12 +122,12 @@ def transformation(points: list) -> list:
     """excecute rotation and symmetry transformation
     on next drawing functions"""
     pts = multiplication(points, processing.__scale)
-    pts = processing.translation(pts)
+    pts = processing.translation_list(pts)
     pts = processing.rotation(pts)
     pts = processing.symetrie_y(pts)
     pts = processing.symetrie_x(pts)
     return pts
 
 if __name__ == '__main__':
-    st = translate(10,10)
-    print(st, translate(*st))
\ No newline at end of file
+    st = translation(10, 10)
+    print(st, translation(*st))
\ No newline at end of file
